<template>
  <div>
    <a-table :columns="columns" :data-source="dataSource" bordered :pagination="false" :size="size" rowKey="fileId"
             :customRow="customRow" :scroll="{y:189}">
      <template slot="fileName" slot-scope="text,record,index">
      <span>
        {{ text }}.{{ record.fileSuffix }}
        <span v-if="record.publishFlag">[当前版本]</span>
      </span>
      </template>
    </a-table>

    <SelectFileCompareModal :dataSource="dataSource" :setCurrentVersionColor="setCurrentVersionColor"
                            ref="selectFileCompareModalRef"/>
  </div>
</template>

<script>
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { getAction } from '@/api/manage'
import dncApi from '@/api/dnc'
import SelectFileCompareModal from './SelectFileCompareModal'

export default {
  name: 'DocumentVersionTableList',
  mixins: [JeecgListMixin],
  components: { SelectFileCompareModal },
  props: {
    currentDocumentInfo: {
      type: Object
    },
    size: {
      type: String
    }
  },
  data() {
    return {
      disableMixinCreated: true,
      queryParams: {},
      columns: [
        {
          title: '序号',
          dataIndex: 'rowIndex',
          width: 65,
          align: 'center',
          customRender: function(t, r, index) {
            return parseInt(index) + 1
          }
        },
        { title: '文件名称', dataIndex: 'fileName', align: 'center', scopedSlots: { customRender: 'fileName' } },
        { title: '版本号', dataIndex: 'docVersion', align: 'center' },
        { title: '文件大小', dataIndex: 'fileSize', align: 'center' }
      ],
      url: {
        list: '/nc/file/find/list'
      }
    }
  },
  created() {
    this.$bus.$on('tableMenuItemMethodTrigger', this.triggerCorrespondingMethod)
  },
  beforeDestroy() {
    this.$bus.$off('tableMenuItemMethodTrigger', this.triggerCorrespondingMethod)
  },
  methods: {
    // 加载列表数据
    loadData() {
      this.dataSource = []
      if (!this.url.list) {
        this.$message.error('请设置url.list属性!')
        return
      }
      var params = this.getQueryParams()//查询条件
      params.docId = this.currentDocumentInfo.docId
      if (!params) {
        return false
      }
      this.loading = true
      getAction(this.url.list, params)
        .then((res) => {
          if (res.success) this.dataSource = res.list
          else {
            that.$notification.error({
              message: '消息',
              description: res.message
            })
          }
        })
        .finally(() => {
          this.loading = false
        })
    },

    /**
     * 指定当前文档为当前版本
     * @param fileId 文件Id
     */
    handleFileAssign({ fileId, publishFlag }) {
      const that = this
      console.log('publishFlag', publishFlag)
      // 如果当前指定版本的版本号与当前版本的版本号一致则不发起请求
      if (publishFlag) {
        that.$notification.info({
          message: '消息',
          description: '当前文档版本即为当前文件'
        })
        return
      }
      dncApi.appointCurrentDocumentVersionApi(fileId)
        .then(res => {
          if (res.success) {
            that.$notification.success({
              message: '消息',
              description: res.message
            })
            that.loadData()
            that.$emit('releaseFilePreviewApi')
          } else {
            that.$notification.error({
              message: '消息',
              description: res.message
            })
          }
        })
        .catch(err => {
          that.$notification.error({
            message: '消息',
            description: err.message
          })
        })
    },

    /**
     * 比对两个版本的文档内容
     * @param _
     * @param modalTitle 弹窗标题
     */
    handleFileAddRelative(_, modalTitle) {
      if (!this.$refs.selectFileCompareModalRef) return
      this.$refs.selectFileCompareModalRef.visible = true
      this.$refs.selectFileCompareModalRef.title = modalTitle
    },

    /**
     * 定制表格行样式及功能
     * @param record 表格行信息
     * @returns {{style: {color: (string)}, on: {contextmenu: *}}} 样式及功能
     */
    customRow(record) {
      return {
        style: {
          color: this.setCurrentVersionColor(record.publishFlag)
        },
        on: {
          contextmenu: event => {
            event.preventDefault()
            this.$emit('handleTableContextMenuOpen', Object.assign({ param: 'file' }, record))
          }
        }
      }
    },

    /**
     * 设置表格中为当前版本的文件表格行颜色标识
     * @param publishFlag 是否为当前版本
     * @returns {string} 颜色标识
     */
    setCurrentVersionColor(publishFlag) {
      return publishFlag ? '#DB9538' : ''
    },

    triggerCorrespondingMethod({ methodName, modalTitle, tableRowInfo }) {
      if (this[methodName]) this[methodName](tableRowInfo, modalTitle)
    }
  }
}
</script>
